==> terraform-0.2.10.tgz: terraform-0.2.10/src/TFWindow.h <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef _TF_WINDOW_H
#define _TF_WINDOW_H


#include "GuiBufferedDrawingArea.h"			// include gtk, gtk--
#include "GuiColormap.h"
#include "GuiColormapLinear.h"
#include "GuiColormapBands.h"
#include "glib--hash.h"


//
// these are the actual menu texts and accelerators 
//
#define MENU_FILE_BRANCH	"/File"
#define MENU_FILE_NEW_BRANCH	"/File/New"
#define MENU_FILE_NEW_SYNTHESIS	"/File/New/Spectral Synthesis"
#define MENU_FILE_NEW_SYNTHESIS_AC "<control>Y"

#define MENU_FILE_NEW_SUBDIVIDE	"/File/New/Subdivision"
#define MENU_FILE_NEW_SUBDIVIDE_AC "<control>D"

#define MENU_FILE_OPEN		"/File/Open"
#define MENU_FILE_OPEN_AC	"<control>O"

#define MENU_FILE_RELOAD	"/File/Reload"
#define MENU_FILE_RELOAD_AC	"<control>R"

#define MENU_FILE_SAVE		"/File/Save"
#define MENU_FILE_SAVE_AC	"<control>S"

#define MENU_FILE_SAVEAS	"/File/Save As ..."
#define MENU_FILE_SAVEAS_AC	"<control>A"

#define MENU_FILE_CLOSE		"/File/Close"
#define MENU_FILE_CLOSE_AC	"<control>C"

#define MENU_FILE_OPTIONS	"/File/Options"
#define MENU_FILE_OPTIONS_AC	"<control>P"

#define MENU_FILE_ABOUT		"/File/About"
#define MENU_FILE_ABOUT_AC	0

#define MENU_FILE_EXIT		"/File/Exit"
#define MENU_FILE_EXIT_AC	"<control>E"



#define MENU_HF_BRANCH		"/HF"
#define MENU_HF_FILL		"/HF/Fill"
#define MENU_HF_FILL_AC		0

#define MENU_HF_FLOWMAP		"/HF/Flowmap"
#define MENU_HF_FLOWMAP_AC	0

#define MENU_HF_FOLD		"/HF/Fold"
#define MENU_HF_FOLD_AC		"<control>F"

#define MENU_HF_INVERT		"/HF/Invert"
#define MENU_HF_INVERT_AC	"<control>I"

#define MENU_HF_LINSCALE	"/HF/Linear Scale"
#define MENU_HF_LINSCALE_AC	"<control>L"

#define MENU_HF_MIRROR		"/HF/Mirror"
#define MENU_HF_MIRROR_AC	0

#define MENU_HF_RESCALE		"/HF/Rescale"
#define MENU_HF_RESCALE_AC	0

#define MENU_HF_ROTATE		"/HF/Rotate"
#define MENU_HF_ROTATE_AC	0

#define MENU_HF_ROUGHEN		"/HF/Roughen"
#define MENU_HF_ROUGHEN_AC	"<control>U"

#define MENU_HF_SMOOTH		"/HF/Smooth"
#define MENU_HF_SMOOTH_AC	"<control>M"

#define MENU_HF_TRANSFORM	"/HF/Transform"
#define MENU_HF_TRANSFORM_AC	"<control>T"

#define MENU_HF_ERODE		"/HF/Erode"
#define MENU_HF_ERODE_AC	0

#define MENU_HF_PLACEPOV	"/HF/Place POV Object"
#define MENU_HF_PLACEPOV_AC	0



#define MENU_VIEW_BRANCH	"/View"
#define MENU_VIEW_2DPLANE 	"/View/2D Plane"
#define MENU_VIEW_2DPLANE_AC 	"<control>1"

#define MENU_VIEW_3DWIRE 	"/View/3D Wire"
#define MENU_VIEW_3DWIRE_AC 	"<control>2"

#define MENU_VIEW_3DHEIGHT	"/View/3D Height"
#define MENU_VIEW_3DHEIGHT_AC	"<control>3"

#define MENU_VIEW_3DLIGHT 	"/View/3D Light"
#define MENU_VIEW_3DLIGHT_AC 	"<control>4"

#define MENU_VIEW_FASTWIRE	"/View/Fast Wireframe"
#define MENU_VIEW_FASTWIRE_AC	"<control>5"

#define MENU_VIEW_AUTOROTATE 	"/View/Auto Rotate"
#define MENU_VIEW_AUTOROTATE_AC "<control>6"



#define MENU_CMAP_BRANCH	"/Colormap"
#define MENU_CMAP_COLORBANDS	"/Colormap/Color Bands"
#define MENU_CMAP_COLORBANDS_AC	"<alt>1"

#define MENU_CMAP_DESERT	"/Colormap/Desert"
#define MENU_CMAP_DESERT_AC	"<alt>2"

#define MENU_CMAP_GRAYSCALE	"/Colormap/Grayscale"
#define MENU_CMAP_GRAYSCALE_AC	"<alt>3"

#define MENU_CMAP_REDHOT	"/Colormap/RedHot"
#define MENU_CMAP_REDHOT_AC	"<alt>4"



/*
 *  TFWindow: the main (drawing) window for terraformer
 */
class TFWindow : public GuiBufferedDrawingArea
	{
	public: 
					TFWindow (); 
					~TFWindow (); 
		virtual void 		quit ();
		virtual void		fileMenuCallback (string m);
		virtual void		hfMenuCallback (string m);
		virtual void		viewMenuCallback (string m);
		virtual void		colormapMenuCallback (string m);
		void			setSize (int x, int y);

	protected: 
		Gtk_Window			d_win;
		Gtk_VBox 			d_vbox;
		Gtk_AccelGroup			d_accelGroup;
		Gtk_ObjectHandle<Gtk_MenuBar> 	d_menuBarHandle;
		Gtk_ItemFactory			*d_itemFactory;
		Glib_Hash			*d_menuHash;	// menu item pointers, path is key

		bool				d_useLinearColormap;
		int				d_nameCount;
		char				**d_mNames;
		GuiColormapLinear		*d_linearColorMap,
						*d_linearColorMap2;
		GuiColormapBands		*d_bandColorMap,
						*d_bandColorMap2;
	};


#endif // _TF_WINDOW_H

==> terraform-0.2.11.tgz: terraform-0.2.11/src/TFWindow.h <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef _TF_WINDOW_H
#define _TF_WINDOW_H


#include "GuiBufferedDrawingArea.h"			// include gtk, gtk--
#include "GuiColormap.h"
#include "GuiColormapLinear.h"
#include "GuiColormapBands.h"
#include "glib--hash.h"


//
// these are the actual menu texts and accelerators 
//
#define MENU_FILE_BRANCH	"/File"
#define MENU_FILE_NEW_BRANCH	"/File/New"
#define MENU_FILE_NEW_SYNTHESIS	"/File/New/Spectral Synthesis"
#define MENU_FILE_NEW_SYNTHESIS_AC "<control>Y"

#define MENU_FILE_NEW_SUBDIVIDE	"/File/New/Subdivision"
#define MENU_FILE_NEW_SUBDIVIDE_AC "<control>D"

#define MENU_FILE_NEW_RANDOM 	"/File/New/Random"
#define MENU_FILE_NEW_RANDOM_AC	"<control>N"

#define MENU_FILE_OPEN		"/File/Open"
#define MENU_FILE_OPEN_AC	"<control>O"

#define MENU_FILE_RELOAD	"/File/Reload"
#define MENU_FILE_RELOAD_AC	"<control>R"

#define MENU_FILE_SAVE		"/File/Save"
#define MENU_FILE_SAVE_AC	"<control>S"

#define MENU_FILE_SAVEAS	"/File/Save As ..."
#define MENU_FILE_SAVEAS_AC	"<control>A"

#define MENU_FILE_CLOSE		"/File/Close"
#define MENU_FILE_CLOSE_AC	"<control>C"

#define MENU_FILE_OPTIONS	"/File/Options"
#define MENU_FILE_OPTIONS_AC	"<control>P"

#define MENU_FILE_ABOUT		"/File/About"
#define MENU_FILE_ABOUT_AC	0

#define MENU_FILE_EXIT		"/File/Exit"
#define MENU_FILE_EXIT_AC	"<control>X"



#define MENU_HF_BRANCH		"/HF"
#define MENU_HF_FILL		"/HF/Fill"
#define MENU_HF_FILL_AC		0

#define MENU_HF_FLOWMAP		"/HF/Flowmap"
#define MENU_HF_FLOWMAP_AC	0

#define MENU_HF_FOLD		"/HF/Fold"
#define MENU_HF_FOLD_AC		"<control>F"

#define MENU_HF_INVERT		"/HF/Invert"
#define MENU_HF_INVERT_AC	"<control>I"

#define MENU_HF_LINSCALE	"/HF/Linear Scale"
#define MENU_HF_LINSCALE_AC	"<control>L"

#define MENU_HF_MIRROR		"/HF/Mirror"
#define MENU_HF_MIRROR_AC	0

#define MENU_HF_RESCALE		"/HF/Rescale"
#define MENU_HF_RESCALE_AC	0

#define MENU_HF_ROTATE		"/HF/Rotate"
#define MENU_HF_ROTATE_AC	0

#define MENU_HF_ROUGHEN		"/HF/Roughen"
#define MENU_HF_ROUGHEN_AC	"<control>U"

#define MENU_HF_SMOOTH		"/HF/Smooth"
#define MENU_HF_SMOOTH_AC	"<control>M"

#define MENU_HF_TRANSFORM	"/HF/Transform"
#define MENU_HF_TRANSFORM_AC	"<control>T"

#define MENU_HF_ERODE		"/HF/Erode"
#define MENU_HF_ERODE_AC	0

#define MENU_HF_PLACEPOV	"/HF/Place POV Object"
#define MENU_HF_PLACEPOV_AC	0



#define MENU_VIEW_BRANCH	"/View"
#define MENU_VIEW_2DPLANE 	"/View/2D Plane"
#define MENU_VIEW_2DPLANE_AC 	"<control>1"

#define MENU_VIEW_3DWIRE 	"/View/3D Wire"
#define MENU_VIEW_3DWIRE_AC 	"<control>2"

#define MENU_VIEW_3DHEIGHT	"/View/3D Height"
#define MENU_VIEW_3DHEIGHT_AC	"<control>3"

#define MENU_VIEW_3DLIGHT 	"/View/3D Light"
#define MENU_VIEW_3DLIGHT_AC 	"<control>4"

#define MENU_VIEW_FASTWIRE	"/View/Fast Wireframe"
#define MENU_VIEW_FASTWIRE_AC	"<control>5"

#define MENU_VIEW_AUTOROTATE 	"/View/Auto Rotate"
#define MENU_VIEW_AUTOROTATE_AC "<control>6"



#define MENU_CMAP_BRANCH	"/Colormap"
#define MENU_CMAP_COLORBANDS	"/Colormap/Color Bands"
#define MENU_CMAP_COLORBANDS_AC	"<alt>1"

#define MENU_CMAP_DESERT	"/Colormap/Desert"
#define MENU_CMAP_DESERT_AC	"<alt>2"

#define MENU_CMAP_GRAYSCALE	"/Colormap/Grayscale"
#define MENU_CMAP_GRAYSCALE_AC	"<alt>3"

#define MENU_CMAP_REDHOT	"/Colormap/RedHot"
#define MENU_CMAP_REDHOT_AC	"<alt>4"



/*
 *  TFWindow: the main (drawing) window for terraformer
 */
class TFWindow : public GuiBufferedDrawingArea
	{
	public: 
					TFWindow (); 
					~TFWindow (); 
		virtual void 		quit ();
		virtual void		fileMenuCallback (string m);
		virtual void		hfMenuCallback (string m);
		virtual void		viewMenuCallback (string m);
		virtual void		colormapMenuCallback (string m);
		void			setSize (int x, int y);

	protected: 
		Gtk_Window			d_win;
		Gtk_VBox 			d_vbox;
		Gtk_AccelGroup			d_accelGroup;
		Gtk_ObjectHandle<Gtk_MenuBar> 	d_menuBarHandle;
		Gtk_ItemFactory			*d_itemFactory;
		Glib_Hash			*d_menuHash;	// menu item pointers, path is key

		bool				d_useLinearColormap;
		int				d_nameCount;
		char				**d_mNames;
		GuiColormapLinear		*d_linearColorMap,
						*d_linearColorMap2;
		GuiColormapBands		*d_bandColorMap,
						*d_bandColorMap2;
	};


#endif // _TF_WINDOW_H
